@@ -1,15 +1,14 @@
 #-*- coding: utf-8 -*-
 
-__version__ = "0.1.2"
-__all__ = ['config', 'register']
-
 from django.core.cache import get_cache
-from django.db import connection
 
 from djconfig.forms import ConfigForm
 from djconfig.config import Config
 from djconfig.models import Config as ConfigModel
-from djconfig.settings import BACKEND
+from djconfig.settings import BACKEND, PREFIX
+
+__version__ = "0.1.3"
+__all__ = ['config', 'register']
 
 
 config = Config()
@@ -29,7 +28,11 @@ def register(form_class):
         "The form does not inherit from ConfigForm"
 
     _registered_forms.add(form_class)
-    _load()
+    load()
+
+
+def prefixer(key):
+    return u"%s:%s" % (PREFIX, key)
 
 
 def load():
@@ -47,25 +50,14 @@ def load():
         form = form_class(data=data)
         form.full_clean()
 
-        initial = {field_name: field.initial
+        initial = {prefixer(field_name): field.initial
                    for field_name, field in form.fields.iteritems()}
         cache_values.update(initial)
 
-        cleaned_data = {field_name: value
+        cleaned_data = {prefixer(field_name): value
                         for field_name, value in form.cleaned_data.iteritems()
                         if field_name in data}
         cache_values.update(cleaned_data)
 
     cache = get_cache(BACKEND)
-    cache.set_many(cache_values)
-
-
-def _load():
-    """
-    Avoids loading if the Config table does not exists.
-    ie: when running syncdb for the first time.
-    """
-    if not ConfigModel._meta.db_table in connection.introspection.table_names():
-        return
-
-    load()
\ No newline at end of file
+    cache.set_many(cache_values)
\ No newline at end of file
