@@ -2,13 +2,13 @@
 
 from django.core.cache import get_cache
 
-from djconfig.settings import BACKEND
+import djconfig
 
 
 class Config(object):
 
     def __init__(self):
-        self._cache = get_cache(BACKEND)
+        self._cache = get_cache(djconfig.BACKEND)
 
     def __getattr__(self, key):
-        return self._cache.get(key)
\ No newline at end of file
+        return self._cache.get(djconfig.prefixer(key))
\ No newline at end of file
